        static void Main(string[] args)
        {
            var SelectedCertificate = LoadCertificateFromSmartCard("Microsoft Base Smart Card Crypto Provider", "40058e2b-51d4-6ced-dd93-b5d5543f7d0a");

            //Creates a new PDF document.

            PdfDocument document = new PdfDocument();

            //Adds a new page.
            PdfPage page = document.Pages.Add();
			
            PdfCertificate pdfCert = new PdfCertificate(SelectedCertificate);

            //Creates a digital signature.

            PdfSignature signature = new PdfSignature(page, pdfCert, "Signature");

            signature.ContactInfo = "johndoe@owned.us";

            signature.LocationInfo = "Honolulu, Hawaii";

            signature.Reason = "I am author of this document.";

            //Saves and closes the document.

            document.Save("Output.pdf");

            document.Close(true);
        }

        public static X509Certificate2 LoadCertificateFromSmartCard(String ProviderName, String KeyContainerName)
        {
            if (String.IsNullOrEmpty(ProviderName) || String.IsNullOrEmpty(KeyContainerName))
            {
                throw new NullReferenceException();
            }

            X509Store store = new X509Store(StoreLocation.CurrentUser);
            store.Open(OpenFlags.ReadOnly | OpenFlags.OpenExistingOnly);
            X509Certificate2 cert = null;

            foreach (X509Certificate2 cert2 in store.Certificates)
            {
                if (cert2.HasPrivateKey)
                {
                    try
                    {
                        RSACryptoServiceProvider rsa = (RSACryptoServiceProvider)cert2.PrivateKey;
                        if (rsa == null) continue;
                        if (rsa.CspKeyContainerInfo.HardwareDevice)
                        {
                            if ((rsa.CspKeyContainerInfo.KeyContainerName.StartsWith(KeyContainerName)) && (rsa.CspKeyContainerInfo.ProviderName == ProviderName))
                            {
                                cert = cert2;
                                break;
                            }
                        }
                    }
                    catch { }
                }
            }

            store.Close();

            return cert;
        }